pub struct HttpRegistryClient { /* private fields */ }Expand description
Lightweight HTTP registry client that operates on a raw base-URL.
Use crate::HttpRegistryClient for the full Registry-aware client with
sparse-index visibility checks, readiness backoff, etc.
Implementations
Sourceimpl HttpRegistryClient
impl HttpRegistryClient
Sourcepub fn with_cache_dir(self, cache_dir: PathBuf) -> Self
pub fn with_cache_dir(self, cache_dir: PathBuf) -> Self
Set the cache directory for sparse index fragments
Sourcepub fn with_timeout(self, timeout: Duration) -> Self
pub fn with_timeout(self, timeout: Duration) -> Self
Set the request timeout
Sourcepub fn crate_exists(&self, name: &str) -> Result<bool>
pub fn crate_exists(&self, name: &str) -> Result<bool>
Check if a crate exists in the registry
Sourcepub fn version_exists(&self, name: &str, version: &str) -> Result<bool>
pub fn version_exists(&self, name: &str, version: &str) -> Result<bool>
Check if a specific version of a crate exists
Sourcepub fn list_owners(&self, name: &str, token: &str) -> Result<OwnersResponse>
pub fn list_owners(&self, name: &str, token: &str) -> Result<OwnersResponse>
List owners for a crate with token-aware lookup.
Sourcepub fn is_owner(&self, name: &str, username: &str) -> Result<bool>
pub fn is_owner(&self, name: &str, username: &str) -> Result<bool>
Check if a user is an owner of a crate
Sourcepub fn is_version_visible_in_sparse_index(
&self,
index_base: &str,
name: &str,
version: &str,
) -> Result<bool>
pub fn is_version_visible_in_sparse_index( &self, index_base: &str, name: &str, version: &str, ) -> Result<bool>
Check if a version exists in sparse-index metadata.